@@ -2,7 +2,11 @@ import React from 'react';
 import QueueMonitor from './QueueMonitor';
 
 function Queues() {
-  return <QueueMonitor />;
+  return (
+    <div className="page-wrapper">
+      <QueueMonitor />
+    </div>
+  );
 }
 
 export default Queues;
\ No newline at end of file
